package com.lantone.structure.facade;

import com.lantone.common.util.StringUtil;
import com.lantone.structure.dto.AnalysisDTO;
import com.lantone.structure.facade.tran.CesareanSectionTran;
import com.lantone.structure.facade.tran.ClinicalBloodTran;
import com.lantone.structure.facade.tran.RescueTran;
import com.lantone.structure.facade.tran.StagesSummaryTran;
import com.lantone.structure.facade.tran.TargetTran;
import com.lantone.structure.vo.AnalysisVO;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.MapUtils;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * @Description:
 * @author: rengb
 * @time: 2020/12/18 16:22
 */
@Slf4j
@Component
public class StructureFacade {

    public AnalysisDTO analysis(AnalysisVO analysisVO) {
        AnalysisDTO analysisDTO = new AnalysisDTO();
        TargetTran targetTran = null;
        switch (analysisVO.getType()) {
            case "剖宫产记录":
                targetTran = new CesareanSectionTran();
                break;
            case "输血记录":
                targetTran = new ClinicalBloodTran();
                break;
            case "抢救记录":
                targetTran = new RescueTran();
                break;
            case "阶段小结":
                targetTran = new StagesSummaryTran();
                break;
            default:
                break;
        }
        try {
            Map<String, String> result = targetTran.convert(analysisVO.getText());
            resultHandle(result);
            analysisDTO.setResult(result);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return analysisDTO;
    }

    private void resultHandle(Map<String, String> result) {
        if (MapUtils.isEmpty(result)) {
            return;
        }
        result.forEach((key, value) -> {
            if (StringUtil.isNotBlank(value)) {
                value = StringUtil.trim(value);
                if (value.endsWith("；") || value.endsWith(";")) {
                    value = value.substring(0, value.length() - 1);
                }
                result.put(key, value);
            }
        });
    }

}